GCM-based inference (Experimental)
==================================

.. toctree::
    :maxdepth: 1
    :glob:

    introduction
    answering_causal_questions/index
    draw_samples
    customizing_model_assignment
    estimating_confidence_intervals
    independence_tests
